@@ -11,6 +11,8 @@ from Products.Archetypes.public import BooleanField
 from xhostplus.social import socialMessageFactory as _
 from xhostplus.social.interfaces import IProductLayer
 
+ToggleSocialButtonsPermission = 'xhostplus.social: Toggle social-buttons option'
+
 class SocialBooleanField(ExtensionField, BooleanField):
     """Toggle button for enabling social buttons."""
 
@@ -32,6 +34,7 @@ class BaseExtender(object):
             ),
             required=False,
             searchable=False,
+            write_permission=ToggleSocialButtonsPermission,
         ),
     ]
 
@@ -40,4 +43,3 @@ class BaseExtender(object):
 
     def getFields(self):
         return self.fields
-
